use std::path::Path;

use serde::Serialize;

use crate::config::Config;
use crate::error::CustomError;
use crate::intermediate::IParagraph;

use super::RenderObject;

#[derive(Debug, Serialize)]
#[serde(tag = "type")]
#[serde(rename = "paragraph")]
pub(crate) struct RenderParagraph {
    children: Vec<RenderObject>,
}

impl RenderParagraph {
    pub(crate) fn new(
        config: &Config,
        output_directory: &Path,
        output_file: &Path,
        paragraph: &IParagraph,
    ) -> Result<RenderParagraph, CustomError> {
        let children = {
            let mut ret = Vec::new();
            for obj in paragraph.children.iter() {
                ret.push(RenderObject::new(
                    config,
                    output_directory,
                    output_file,
                    obj,
                )?);
            }
            ret
        };

        Ok(RenderParagraph { children })
    }
}
